@@ -1,4 +1,4 @@
-describe "standard_activerecord", adapter: :ActiveRecord, mysql: true, broken: ::Gem::Version.new(RUBY_ENGINE_VERSION) >= ::Gem::Version.new('3.0.0') do
+describe "standard_activerecord", adapter: :ActiveRecord, mysql: true do
   moneta_store :ActiveRecord do
     {
       table: 'standard_activerecord',
@@ -15,7 +15,7 @@ describe "standard_activerecord", adapter: :ActiveRecord, mysql: true, broken: :
   end
 
   moneta_loader do |value|
-    ::Marshal.load(value.unpack('m').first)
+    ::Marshal.load(value.unpack1('m'))
   end
 
   moneta_specs STANDARD_SPECS.with_each_key
