@@ -1,4 +1,4 @@
-describe "standard_activerecord_with_expires", adapter: :ActiveRecord, mysql: true, broken: ::Gem::Version.new(RUBY_ENGINE_VERSION) >= ::Gem::Version.new('3.0.0') do
+describe "standard_activerecord_with_expires", adapter: :ActiveRecord, mysql: true do
   let(:t_res) { 0.125 }
   let(:min_ttl) { t_res }
   use_timecop
@@ -21,7 +21,7 @@ describe "standard_activerecord_with_expires", adapter: :ActiveRecord, mysql: tr
 
 
   moneta_loader do |value|
-    ::Marshal.load(value.unpack('m').first)
+    ::Marshal.load(value.unpack1('m'))
   end
 
   moneta_specs STANDARD_SPECS.with_expires.with_each_key
