@@ -19,7 +19,7 @@ describe "standard_datamapper_with_expires", unsupported: defined?(JRUBY_VERSION
   end
 
   moneta_loader do |value|
-    ::Marshal.load(value.unpack('m').first)
+    ::Marshal.load(value.unpack1('m'))
   end
 
   moneta_specs STANDARD_SPECS.without_increment.with_expires
