@@ -20,6 +20,6 @@ describe 'adapter_memcached_dalli', retry: 3, adapter: :Memcached do
       Moneta::Adapters::MemcachedDalli.new(server: '127.0.0.1:11212', expires: min_ttl)
     end
 
-    moneta_specs NATIVE_EXPIRY_SPECS.with_default_expires
+    moneta_specs DEFAULT_EXPIRES_SPECS
   end
 end
