@@ -12,5 +12,5 @@ describe 'expires_memory_with_default_expires', isolate: true, proxy: :Expires d
     end
   end
 
-  moneta_specs STANDARD_SPECS.without_transform.with_expires.with_default_expires.without_persist.returnsame.with_each_key
+  moneta_specs DEFAULT_EXPIRES_SPECS
 end
