@@ -8,7 +8,7 @@ describe 'transformer_marshal_base64', proxy: :Transformer do
   end
 
   moneta_loader do |value|
-    ::Marshal.load(value.unpack('m').first)
+    ::Marshal.load(value.unpack1('m'))
   end
 
   moneta_specs STANDARD_SPECS.without_persist.with_each_key
